@@ -65,7 +65,6 @@ use subs qw(
 	BAD_CHECKSUM
 	GOOD_ISBN
 	BAD_ISBN
-	ARTICLE_CODE_OUT_OF_RANGE
 	);
 use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS $debug %group_data
 	$MAX_GROUP_CODE_LENGTH %ERROR_TEXT );
@@ -73,7 +72,7 @@ use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS $debug %group_data
 use Carp qw(carp croak cluck);
 use base qw(Exporter);
 
-use Business::ISBN::Data 20140910.002; # now a separate module
+use Business::ISBN::Data 20120719.001; # now a separate module
 # ugh, hack
 *group_data = *Business::ISBN::country_data;
 sub _group_data { $group_data{ $_[1] } }
@@ -94,12 +93,12 @@ sub _publisher_ranges {
 	[ @{ $self->_group_data( $self->group_code )->[1] } ];
 	}
 
-my $debug = $ENV{BUSINESS_ISBN_DEBUG};
+my $debug = 0;
 
 BEGIN {
 	@EXPORT_OK = qw(
 		INVALID_GROUP_CODE INVALID_PUBLISHER_CODE
-		BAD_CHECKSUM GOOD_ISBN BAD_ISBN ARTICLE_CODE_OUT_OF_RANGE
+		BAD_CHECKSUM GOOD_ISBN BAD_ISBN
 		INVALID_PREFIX
 		%ERROR_TEXT
 		valid_isbn_checksum
@@ -110,15 +109,15 @@ BEGIN {
 		);
 	};
 
-$VERSION = "2.011_01";
+$VERSION = "2.06";
+
+sub INVALID_PREFIX         () { -4 };
+sub INVALID_GROUP_CODE     () { -2 };
+sub INVALID_PUBLISHER_CODE () { -3 };
+sub BAD_CHECKSUM           () { -1 };
+sub GOOD_ISBN              () {  1 };
+sub BAD_ISBN               () {  0 };
 
-sub ARTICLE_CODE_OUT_OF_RANGE () { -5 }
-sub INVALID_PREFIX            () { -4 };
-sub INVALID_GROUP_CODE        () { -2 };
-sub INVALID_PUBLISHER_CODE    () { -3 };
-sub BAD_CHECKSUM              () { -1 };
-sub GOOD_ISBN                 () {  1 };
-sub BAD_ISBN                  () {  0 };
 
 %ERROR_TEXT = (
 	 0 => "Bad ISBN",
@@ -127,7 +126,6 @@ sub BAD_ISBN                  () {  0 };
 	-2 => "Invalid group code",
 	-3 => "Invalid publisher code",
 	-4 => "Invalid prefix (must be 978 or 979)",
-	-5 => "Incremented article code would be out of range",
 	);
 
 use Business::ISBN10;
@@ -183,11 +181,10 @@ digit, 'x', or 'X'.
 The constructor attempts to determine the group code and the publisher
 code.  If these data cannot be determined, the constructor sets C<<
 $obj->error >> to something other than C<GOOD_ISBN>. An object is
-still returned and it is up to the program to check the C<< error >> method
-for one of five values or one of the C<< error_* >> methods to check for
-a particular error. The actual
+still returned and it is up to the program to check C<< $obj->error >>
+for one of five values (which may be exported on demand). The actual
 values of these symbolic versions are the same as those from previous
-versions of this module which used literal values:
+versions of this module which used literal values.
 
 
 	Business::ISBN::INVALID_PUBLISHER_CODE
@@ -198,13 +195,10 @@ versions of this module which used literal values:
 
 If you have one of these values and want to turn it into a string, you
 can use the C<%Business::ISBN::ERROR_TEXT> hash, which is exportable
-by asking for it explicitly in the import list:
+by asking for it explicitly in the import list.
 
 	use Business::ISBN qw(%ERROR_TEXT);
 
-As of version 2.010_01, you can get this text from C<< error_text >>
-so you don't have to import anything.
-
 The string passed as the ISBN need not be a valid ISBN as long as it
 superficially looks like one.  This allows one to use the
 C<fix_checksum()> method.  Despite the disclaimer in the discussion of
@@ -298,43 +292,7 @@ value is a key in %ERROR_TEXT.
 
 =cut
 
-sub error { $_[0]->{'valid'} < 1 and $_[0]->{'valid'} }
-
-=item error_is_bad_group
-
-=item error_is_bad_publisher
-
-=item error_is_article_out_of_range
-
-=item error_is_bad_checksum
-
-Returns true if the ISBN error is that type.
-
-=cut
-
-sub error_is_bad_group {
-	return $_[0]->error == INVALID_GROUP_CODE;
-	}
-
-sub error_is_bad_publisher {
-	return $_[0]->error == INVALID_PUBLISHER_CODE;
-	}
-
-sub error_is_article_out_of_range {
-	return $_[0]->error == ARTICLE_CODE_OUT_OF_RANGE;
-	}
-
-sub error_is_bad_checksum {
-	return $_[0]->error == BAD_CHECKSUM;
-	}
-
-=item error_text
-
-Returns a text version of the error text
-
-=cut
-
-sub error_text { $ERROR_TEXT{$_[0]->{'valid'}} }
+sub error { $_[0]->{'valid'} }
 
 =item is_valid
 
@@ -415,30 +373,6 @@ uniquely identifies the item.
 
 sub article_code { $_[0]->{'article_code'} }
 
-=item article_code_length
-
-Returns the article code length for the ISBN.
-
-=cut
-
-sub article_code_length { length $_[0]->{'article_code'} }
-
-=item article_code_min
-
-Returns the minimum article code length for the publisher code.
-
-=cut
-
-sub article_code_min { 0 }
-
-=item article_code_max
-
-Returns the max article code length for the publisher code.
-
-=cut
-
-sub article_code_max { '9' x $_[0]->article_code_length }
-
 =item checksum
 
 Returns the checksum code for the ISBN. This checksum may not be valid since
@@ -494,7 +428,7 @@ sub fix_checksum {
 	}
 
 
-=item as_string(), as_string([])
+=item as_string(),  as_string([])
 
 Return the ISBN as a string.  This function takes an
 optional anonymous array (or array reference) that specifies
@@ -567,30 +501,19 @@ sub as_isbn13 {
 =item xisbn
 
 In scalar context, returns an anonymous array of related ISBNs using xISBN.
-In list context, returns a list. It does not include the original ISBN.
+In list context, returns a list.
 
-This feature requires C<LWP::Simple> or C<Mojo::UserAgent>.
+This feature requires C<LWP::Simple>.
 
 =cut
 
 sub xisbn {
 	my $self = shift;
-	carp "The xisbn service was due to be turned off on March 15, 2016.";
-	carp "The xisbn method is deprecated.";
 
 	my $data = $self->_get_xisbn;
 	$data =~ tr/x/X/;
 
-	my @isbns = do {
-		if( eval "require Mojo::DOM; 1" ) {
-			my $dom = Mojo::DOM->new( $data );
-			$dom->find( 'isbn' )->map('text')->each;
-			}
-		else {
-			$data =~ m|<isbn.*?>(.*?)</isbn>|g;
-			}
-		};
-
+	my @isbns = $data =~ m|<isbn>(.*?)</isbn>|ig;
 	shift @isbns;
 	wantarray ? @isbns : \@isbns;
 	}
@@ -598,18 +521,10 @@ sub xisbn {
 sub _get_xisbn {
 	my $self = shift;
 
-	my $data = eval {
-		if( eval "require Mojo::UserAgent; 1" ) {
-			Mojo::UserAgent->new->get( $self->_xisbn_url )->res->text;
-			}
-		elsif( eval "require LWP::Simple; 1" ) {
-			LWP::Simple::get( $self->_xisbn_url );
-			}
-		else {
-			carp "Could not load either Mojo::UserAgent or LWP::Simple to fetch xISBN\n";
-			return;
-			}
-		};
+	eval "use LWP::Simple";
+	if( $@ ) { carp "You need LWP::Simple to use xisbn()"; return; }
+
+	my $data = LWP::Simple::get( $self->_xisbn_url );
 
 	carp "Could not fetch xISBN data" unless defined $data;
 
@@ -623,72 +538,6 @@ sub _xisbn_url {
 	return "http://xisbn.worldcat.org/xid/isbn/$isbn";
 	}
 
-=item increment
-
-Returns the next C<Business::ISBN> by incrementing the article code of
-the specified ISBN (object or scalar).
-
-Returns undef, if the parameter is invalid or equals the maximum
-possible ISBN for the publisher.
-
-	$isbn = Business::ISBN->new('1565922573');  # 1-56592-257-3
-	$next_isbn = $isbn->increment;              # 1-56592-258-1
-
-If the next article code would exceed the maximum possible article
-code (such as incrementing 999 to 1000), this returns ARTICLE_CODE_OUT_OF_RANGE
-as the error.
-
-=cut
-
-sub increment { $_[0]->_step_article_code( +1 ) }
-
-=item decrement
-
-Returns the previous C<Business::ISBN> by decrementing the article
-code of the specified ISBN (object or scalar).
-
-Returns undef, if the parameter is invalid or equals the minimum
-possible ISBN for the publisher.
-
-	$isbn = Business::ISBN->new('1565922573');  # 1-56592-257-3
-	$prev_isbn = $isbn->decrement;              # 1-56592-256-5
-
-If the next article code would exceed the maximum possible article
-code (such as incrementing 000 to -1), this returns ARTICLE_CODE_OUT_OF_RANGE
-as the error.
-
-=cut
-
-sub decrement { $_[0]->_step_article_code( -1 ) }
-
-sub _step_article_code {
-	my( $self, $step ) = @_;
-	carp "The step for _step_isbn must be an integer"
-		unless( $step == int $step and $step != 0 );
-
-	my $next_article_code = int $self->article_code + $step;
-
-	return ARTICLE_CODE_OUT_OF_RANGE unless
-		$next_article_code >= $self->article_code_min
-			&&
-		$next_article_code <= $self->article_code_max
-		;
-
-	my $next_isbn = Business::ISBN->new(
-		join('',
-			$self->prefix,
-			$self->group_code,
-			$self->publisher_code,
-			sprintf( "%0*d", $self->article_code_length, $next_article_code ),
-			'0'
-			)
-		);
-
-	$next_isbn->fix_checksum;
-
-	$next_isbn;
-	}
-
 =item png_barcode
 
 Returns image data in PNG format for the barcode for the ISBN. This
@@ -936,7 +785,7 @@ __END__
 
 This source is in Github:
 
-    https://github.com/briandfoy/business-isbn
+    https://github.com/briandfoy/business--isbn
 
 =head1 AUTHOR
 
@@ -944,7 +793,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2001-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2001-2013, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
@@ -959,6 +808,4 @@ and testing.
 Ed Summers C<< <esummers@cpan.org> >> has volunteered to help with
 this module.
 
-Markus Spann C<< <markus_spann@gmx.de> >> added C<increment> and C<decrement>.
-
 =cut
